diff libpurple/connection.h @ 20792:682543aced31

Split the "you don't have SSL support" meaning of PURPLE_REASON_ENCRYPTION_ERROR into a new reason, PURPLE_REASON_NO_SSL_SUPPORT. This will let UIs give proper errors that reference the SSLfaq!
author Will Thompson <will.thompson@collabora.co.uk>
date Sat, 06 Oct 2007 12:05:22 +0000
parents 57e9d1ecefff
children 88aa557b997f
line wrap: on
line diff
--- a/libpurple/connection.h	Fri Oct 05 18:40:05 2007 +0000
+++ b/libpurple/connection.h	Sat Oct 06 12:05:22 2007 +0000
@@ -70,8 +70,13 @@
 	 *  server offered.
 	 */
 	PURPLE_REASON_AUTHENTICATION_IMPOSSIBLE,
-	/** There was an error negotiating SSL on this connection, or encryption
-	 *  was unavailable and an account option was set to require it.
+	/** libpurple was built without SSL support, and the connection needs
+	 *  SSL.
+	 */
+	PURPLE_REASON_NO_SSL_SUPPORT,
+	/** There was an error negotiating SSL on this connection, or the
+	 *  server does not support encryption but an account option was set to
+	 *  require it.
 	 */
 	PURPLE_REASON_ENCRYPTION_ERROR,
 	/** Someone is already connected to the server using the name you are